@@ -37,12 +37,12 @@ class GunicornLogger(Logger):
         log_format = self._log_format_pairs.copy()
         if self.include_request_headers:
             log_format["request_headers"] = {}
-            for k in req.headers.keys():
+            for k, _ in req.headers:
                 log_format["request_headers"][k.lower()] = f"%({{{k.lower()}}}i)s"
 
         if self.include_response_headers:
             log_format["response_headers"] = {}
-            for k in resp.headers.keys():
+            for k, _ in resp.headers:
                 log_format["response_headers"][k.lower()] = f"%({{{k.lower()}}}o)s"
 
         if hasattr(self, "get_custom_variables"):
