@@ -53,7 +53,8 @@ class GCloudGunicornAccesLogger(GunicornLogger):
         Returns:
             dict -- custom env variables
         """
-        trace = req.headers.get("X-Cloud-Trace-Context")
-        if trace:
-            trace = f"projects/{self.project_id}/traces/{trace.split('/')[0]}"
+        trace = ""
+        for k, value in req.headers:
+            if k == "X-Cloud-Trace-Context":
+                trace = f"projects/{self.project_id}/traces/{value.split('/')[0]}"
         return {"logging.googleapis.com/trace": trace}
